'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var core = require('@babel/core');
var helperPluginUtils = require('@babel/helper-plugin-utils');

var transformPlugin = /*#__PURE__*/helperPluginUtils.declare(function (_, options) {
  return {
    name: '@kaze-style/babel-plugin-transform',
    pre: function pre() {
      this.importDeclarationPaths = [];
      this.calleePaths = [];
      this.definitionPaths = [];
    },
    visitor: {
      Program: {
        exit: function exit(_, state) {
          if (state.definitionPaths) {
            var classesList = options.resolvedStyles.map(function (resolvedStyle) {
              return resolvedStyle.classes;
            });
            state.definitionPaths.forEach(function (_definitionPath, index) {
              var definitionPath = _definitionPath;
              var callExpressionPath = definitionPath.findParent(function (parentPath) {
                return parentPath.isCallExpression();
              });
              callExpressionPath.node.arguments = [core.types.valueToNode(classesList[index])];
            });
          }

          if (state.importDeclarationPaths) {
            state.importDeclarationPaths.forEach(function (importDeclarationPath) {
              var specifiers = importDeclarationPath.get('specifiers');
              specifiers.forEach(function (specifier) {
                if (specifier.isImportSpecifier()) {
                  var importedPath = specifier.get('local');

                  if (importedPath.isIdentifier({
                    name: options["import"].name
                  })) {
                    specifier.replaceWith(core.types.identifier(options["import"].transformName));
                  }
                }
              });
            });
          }

          if (state.calleePaths) {
            state.calleePaths.forEach(function (calleePath) {
              calleePath.replaceWith(core.types.identifier(options["import"].transformName));
            });
          }
        }
      },
      ImportDeclaration: function ImportDeclaration(path, state) {
        if (path.node.source.value === options["import"].source) {
          var _state$importDeclarat;

          (_state$importDeclarat = state.importDeclarationPaths) == null ? void 0 : _state$importDeclarat.push(path);
        }
      },
      CallExpression: function CallExpression(path, state) {
        var calleePath = path.get('callee');

        if (this.importDeclarationPaths && calleePath.referencesImport(options["import"].source, options["import"].name)) {
          var argumentPaths = path.get('arguments');

          if (Array.isArray(argumentPaths) && argumentPaths.length === 1) {
            var definitionsPath = argumentPaths[0];

            if (definitionsPath != null && definitionsPath.isObjectExpression()) {
              var _state$definitionPath, _state$calleePaths;

              (_state$definitionPath = state.definitionPaths) == null ? void 0 : _state$definitionPath.push(definitionsPath);
              (_state$calleePaths = state.calleePaths) == null ? void 0 : _state$calleePaths.push(calleePath);
            }
          }
        }
      }
    }
  };
});

var kazePreset = function kazePreset(_, options) {
  return {
    plugins: [[transformPlugin, options]]
  };
};

exports.default = kazePreset;
exports.kazePreset = kazePreset;
//# sourceMappingURL=babel-plugin.cjs.development.js.map
